@@ -4,11 +4,11 @@ import json
 from hashlib import md5
 import os
 
-from pyrez.enumerations import (
+from pyrezfix.enumerations import (
     Format,
     Language,
 )
-from pyrez.exceptions import (
+from pyrezfix.exceptions import (
     DailyLimit,
     IdOrAuthEmpty,
     InvalidArgument,
@@ -23,8 +23,8 @@ from pyrez.exceptions import (
     PrivatePlayer,
     #UnexpectedException,
 )
-from pyrez.events import Event
-from pyrez.models import (
+from pyrezfix.events import Event
+from pyrezfix.models import (
     APIResponse,
     DataUsed,
     Friend,
