@@ -1,5 +1,5 @@
 from .APIResponse import APIResponse
-from pyrez.models.Mixin import MatchId
+from pyrezfix.models.Mixin import MatchId
 class DemoDetails(APIResponse, MatchId):
     def __init__(self, **kwargs):
         APIResponse.__init__(self, **kwargs)
