@@ -1,5 +1,5 @@
 from .APIResponseBase import APIResponseBase
-from pyrez.models.Mixin import Player as PlayerMixin
+from pyrezfix.models.Mixin import Player as PlayerMixin
 class MergedPlayer(APIResponseBase, PlayerMixin):
     def __init__(self, **kwargs):
         APIResponseBase.__init__(self, **kwargs)
