@@ -1,6 +1,6 @@
 
-from pyrez.enumerations import Champions
-from pyrez.models import APIResponse
+from pyrezfix.enumerations import Champions
+from pyrezfix.models import APIResponse
 class BountyItem(APIResponse):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
