@@ -1,5 +1,5 @@
-from pyrez.enumerations import Champions
-from pyrez.models import God as BaseCharacter
+from pyrezfix.enumerations import Champions
+from pyrezfix.models import God as BaseCharacter
 from .ChampionAbility import ChampionAbility
 class Champion(BaseCharacter):
     def __init__(self, **kwargs):
