@@ -1,5 +1,5 @@
-from pyrez.enumerations import Champions
-from pyrez.models import Item as ItemBase
+from pyrezfix.enumerations import Champions
+from pyrezfix.models import Item as ItemBase
 class Item(ItemBase):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
