@@ -1,5 +1,5 @@
-from pyrez.enumerations import Champions
-from pyrez.models import APIResponse
+from pyrezfix.enumerations import Champions
+from pyrezfix.models import APIResponse
 from .LoadoutItem import LoadoutItem
 class Loadout(APIResponse):
     def __init__(self, **kwargs):
