@@ -1,5 +1,5 @@
 from .APIResponse import APIResponse
-from pyrez.models.Mixin import Player as PlayerMixin
+from pyrezfix.models.Mixin import Player as PlayerMixin
 class Player(APIResponse, PlayerMixin):
     def __init__(self, **kwargs):
         APIResponse.__init__(self, **kwargs)
