@@ -1,6 +1,6 @@
 from datetime import datetime
 from .APIResponse import APIResponse
-from pyrez.models.Mixin import Player as PlayerMixin
+from pyrezfix.models.Mixin import Player as PlayerMixin
 class PlayerBase(APIResponse, PlayerMixin):
     def __init__(self, **kwargs):
         APIResponse.__init__(self, **kwargs)
