@@ -1,7 +1,7 @@
 from datetime import datetime
 from .APIResponse import APIResponse
-from pyrez.enumerations import Champions, Gods
-from pyrez.models.Mixin import KDA, Player as PlayerMixin, Winratio
+from pyrezfix.enumerations import Champions, Gods
+from pyrezfix.models.Mixin import KDA, Player as PlayerMixin, Winratio
 class QueueStats(APIResponse, KDA, PlayerMixin, Winratio):
     def __init__(self, **kwargs):
         APIResponse.__init__(self, **kwargs)#super().__init__(**kwargs)
