@@ -1,6 +1,6 @@
-from pyrez.enumerations import Tier
+from pyrezfix.enumerations import Tier
 from .APIResponse import APIResponse
-from pyrez.models.Mixin import Player as PlayerMixin, Winratio
+from pyrezfix.models.Mixin import Player as PlayerMixin, Winratio
 class Ranked(APIResponse, PlayerMixin, Winratio):
     def __init__(self, **kwargs):
         APIResponse.__init__(self, **kwargs)#super().__init__(**kwargs)
