@@ -1,4 +1,4 @@
-from pyrez.models import APIResponse
+from pyrezfix.models import APIResponse
 from .Match import Match
 class MatchHistory(APIResponse):
     def __init__(self, **kwargs):
