@@ -1,4 +1,4 @@
-from pyrez.models import PlayerBase
+from pyrezfix.models import PlayerBase
 class Player(PlayerBase):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
