@@ -1,6 +1,6 @@
-from pyrez.enumerations import Champions, Gods
-from pyrez.models import APIResponse
-from pyrez.models.Mixin import Winratio
+from pyrezfix.enumerations import Champions, Gods
+from pyrezfix.models import APIResponse
+from pyrezfix.models.Mixin import Winratio
 class GodLeaderboard(APIResponse, Winratio):
     def __init__(self, **kwargs):
         APIResponse.__init__(self, **kwargs)#super().__init__(**kwargs)
