@@ -1,5 +1,5 @@
-from pyrez.models import APIResponse
-from pyrez.enumerations import Gods
+from pyrezfix.models import APIResponse
+from pyrezfix.enumerations import Gods
 class GodRecommendedItem(APIResponse):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
