@@ -1,5 +1,5 @@
-from pyrez.models import Skin
-from pyrez.enumerations import Gods
+from pyrezfix.models import Skin
+from pyrezfix.enumerations import Gods
 class GodSkin(Skin):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
