@@ -1,4 +1,4 @@
-from pyrez.models import PlayerPS, Ranked
+from pyrezfix.models import PlayerPS, Ranked
 class Player(PlayerPS):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -19,10 +19,10 @@ class Player(PlayerPS):
         self.rankedJoust = kwargs.get("RankedJoust", None)
         if self.rankedJoust and isinstance(self.rankedJoust, dict):
             self.rankedJoust = Ranked(**self.rankedJoust)
-        
+
         self.rankedJoustController = kwargs.get("RankedJoustController", None)
         if self.rankedJoustController and isinstance(self.rankedJoustController, dict):
             self.rankedJoustController = Ranked(**self.rankedJoustController)
-        
+
         self.tierJoust = kwargs.get("Tier_Joust", '') or ''
         self.tierDuel = kwargs.get("Tier_Duel", '') or ''
