@@ -1,5 +1,5 @@
-from pyrez.models import APIResponse
-from pyrez.models.Mixin import Winratio
+from pyrezfix.models import APIResponse
+from pyrezfix.models.Mixin import Winratio
 class Info(APIResponse, Winratio):
     def __init__(self, **kwargs):
         APIResponse.__init__(self, **kwargs)
