@@ -1,4 +1,4 @@
-from pyrez.models import APIResponse
+from pyrezfix.models import APIResponse
 class Search(APIResponse):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
