@@ -1,5 +1,5 @@
-from pyrez.models import APIResponse
-from pyrez.models.Mixin import MatchId
+from pyrezfix.models import APIResponse
+from pyrezfix.models.Mixin import MatchId
 class TopMatch(APIResponse, MatchId):
     def __init__(self, **kwargs):
         APIResponse.__init__(self, **kwargs)
