@@ -1,4 +1,4 @@
-from pyrez.models import APIResponseBase
+from pyrezfix.models import APIResponseBase
 class AffectedComponents(APIResponseBase):
     def __init__(self, **kwargs):
     	super().__init__(**kwargs)
