@@ -1,4 +1,4 @@
-from pyrez.models import APIResponseBase
+from pyrezfix.models import APIResponseBase
 from .Page import Page
 class Base(APIResponseBase):
     def __init__(self, **kwargs):
